# The fritzing-app repo does not contain a tag for v1.0.5
# The app commit we're using is dated 2025-04-02
%define git      b9add9eaa7c426963de20c8514a69d3f15e83bdf
%define gitparts 4f7d39b22a6c307e6cca62c7f78eae96696e8b2c

Name:           fritzing
Version:        1.0.5
Release:        %mkrel 2
Summary:        Electronic Design Automation software; from prototype to product
License:        GPLv3+, CC-BY-SA
Group:          Sciences/Other
Url:            https://fritzing.org/
Source0:        https://github.com/fritzing/fritzing-app/archive/%{git}/%{name}-app-%{git}.tar.gz
# The fritzing-parts repository no longer uses git tags for marking releases.
# There is a "release_0.9.6" branch in the repository, though.
# Take the latest commit from that branch (as of 2023-12-20).
Source1:        https://github.com/fritzing/fritzing-parts/archive/%{gitparts}/%{name}-parts-%{gitparts}.tar.gz
Source2:        https://github.com/svgpp/svgpp/archive/v1.3.1/svgpp-1.3.1.tar.gz
# Taken from fedora until a fix for issue 3796
Source3:        parts.db
# Mageia-specific patch to disable internal auto-updating feature
Patch0:         0000-disable-autoupdate.patch
# Use the system quazip library instead of the bundled one and
# upgrade to Quazip Qt6 V1.x
Patch1:         0001-unbundle-quazip.patch
# Remove references to example sketches that use twitter4j library
Patch2:         0002-remove-twitter4j.patch
# use system libgit2
Patch3:         fritzing-0.9.10-use-system-libgit2.patch
# use system polyclipping (clipper)
Patch4:         0003-unbundle-clipper.patch

BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(ngspice)
BuildRequires:  pkgconfig(polyclipping)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6SerialPort)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(QuaZip-Qt6)
BuildRequires:  boost-devel
BuildRequires:  desktop-file-utils
BuildRequires:  qttools6

# mga#24115
Requires:       qt6-database-plugin-sqlite

%description
Fritzing is an open-source initiative to support designers, artists,
researchers and hobbyists to take the step from physical prototyping
to actual product. It is in the spirit of Processing and Arduino which
allows users to document their Arduino and other electronic-based
prototypes, and to create a PCB layout for manufacturing.

%prep
%setup -q -n %{name}-app-%{git}
tar -xf %{SOURCE1}
mv %{name}-parts-%{gitparts}/ parts/

tar -xf %{SOURCE2}

# Remove some GitHub-specific files
rm -rf .github || true
rm -rf parts/.github || true

# The TwitterSaurus examples use (a bundled) twitter4j library, whose license
# is incompatible with Mageia.
rm -f sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Fritzing/TwitterSaurus.fzz
rm -f sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Processing/twitter4j-core-2.2.5.jar
rm -rf sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Processing/TwitterSaurus*
rm -f sketches/core/obsolete/TwitterSaurus.fzz

# Remove a <url> entry which causes the appstream file to fail validation.
sed -e '/<url type="forum">/d' -i 'org.fritzing.Fritzing.appdata.xml'

# Detect system ngspice header library
sed -i 's|NGSPICEPATH = ../../ngspice-42|NGSPICEPATH = %{_includedir}/ngspice|' pri/spicedetect.pri
# Detect bundled svgpp header-only library
sed -i 's|$$PWD/../../svgpp-1.3.1|$$PWD/../svgpp-1.3.1|g' pri/svgppdetect.pri

# Fix qt version check (upstream recommend 6.5.3 at use, why???)
sed -i 's|QT_MOST=6.5.10|QT_MOST=6.8.10|' phoenix.pro

%autopatch -p1

%build
# Detect Quazip 1.5
sed -i 's|QUAZIP_VERSION=1.4|QUAZIP_VERSION=1.5|' pri/quazipdetect.pri
# build translations
%{_qt6_libexecdir}/lrelease-pro phoenix.pro

CXXFLAGS="%{optflags}"
%qmake_qt6
%make_build

./Fritzing -platform minimal -f ./parts -db ./parts/parts.db

%install
%make_install INSTALL_ROOT=%{buildroot}

ln -s %{_bindir}/Fritzing %{buildroot}%{_bindir}/%{name}
cp -f %{buildroot}%{_mandir}/man1/Fritzing.1 %{buildroot}%{_mandir}/man1/fritzing.1

%files
%doc README.md
%license LICENSE.GPL2 LICENSE.GPL3 LICENSE.CC-BY-SA
%{_bindir}/Fritzing
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.%{name}.Fritzing.desktop
%{_metainfodir}/org.%{name}.Fritzing.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/*


%changelog
* Sat Jun 14 2025 daviddavid <daviddavid> 1.0.5-2.mga10
+ Revision: 2191330
- fix for detecting quazip 1.5
- rebuild for new quazip 1.5

* Wed Apr 30 2025 daviddavid <daviddavid> 1.0.5-1.mga10
+ Revision: 2180116
- new version: 1.0.5

* Thu Apr 10 2025 daviddavid <daviddavid> 1.0.4-1.mga10
+ Revision: 2174524
- new version: 1.0.4

* Fri Sep 20 2024 papoteur <papoteur> 1.0.3-4.mga10
+ Revision: 2099566
- rebuild for libgit2 1.8.1

* Sat Jul 06 2024 daviddavid <daviddavid> 1.0.3-3.mga10
+ Revision: 2080157
- create our own part.db file during build as it seems to work now

* Sat Jul 06 2024 daviddavid <daviddavid> 1.0.3-2.mga10
+ Revision: 2080142
- update parts.db accordingly with current 1.0.3 release

* Sat Jul 06 2024 daviddavid <daviddavid> 1.0.3-1.mga10
+ Revision: 2080082
- new version: 1.0.3

* Tue Jan 09 2024 daviddavid <daviddavid> 1.0.2-1.mga10
+ Revision: 2029296
- new version: 1.0.2

* Sun Sep 03 2023 daviddavid <daviddavid> 1.0.0-1.mga10
+ Revision: 1983876
- new version: 1.0.0
- switch to Qt6
- disable again auto-update feature

* Sat Sep 02 2023 daviddavid <daviddavid> 0.9.10-3.mga10
+ Revision: 1983627
- rebuild for new quazip 1.4

* Thu Mar 23 2023 daviddavid <daviddavid> 0.9.10-2.mga9
+ Revision: 1950168
- drop no more needed by the project Qt5WebKit build dependency

* Mon Nov 21 2022 daviddavid <daviddavid> 0.9.10-1.mga9
+ Revision: 1909652
- new version: 0.9.10
- remove bundled twitter4j library (license is incompatible)

* Wed Nov 09 2022 papoteur <papoteur> 0.9.6-5.mga9
+ Revision: 1904887
- rebuild for qt5-quazip 1.3

* Tue Apr 05 2022 umeabot <umeabot> 0.9.6-4.mga9
+ Revision: 1845364
- Mageia 9 Mass Rebuild

* Mon Jan 03 2022 wally <wally> 0.9.6-3.mga9
+ Revision: 1766335
- rebuild for libgit2 1.3.0

* Wed May 19 2021 daviddavid <daviddavid> 0.9.6-2.mga9
+ Revision: 1725545
- switch to new quazip 1.0
- workaround the parts.db file until an upstream fix
- generate the parts database (parts.db)

* Sun Mar 14 2021 daviddavid <daviddavid> 0.9.6-1.mga9
+ Revision: 1702638
- new version: 0.9.6
- drop quazip5 patch (build against system quazip library - now supported upstream)
- rebase libgit2 and port-remaining-of-the-scripts-to-python3 patches

* Wed Dec 30 2020 luigiwalser <luigiwalser> 0.9.4-4.git20191201.mga8
+ Revision: 1666238
- rebuild for libgit2

* Wed Dec 16 2020 umeabot <umeabot> 0.9.4-3.git20191201.mga8
+ Revision: 1658485
- Rebuild for new Qt5

* Fri Jul 24 2020 daviddavid <daviddavid> 0.9.4-2.git20191201.mga8
+ Revision: 1608631
- rebuild for new libgit2 1.0.1
- add support for libgit2 >= 1.0

* Wed Feb 19 2020 daviddavid <daviddavid> 0.9.4-1.git20191201.mga8
+ Revision: 1544395
- new version: 0.9.4 (CD-498)
- remove merged upstream patches
- add patch to port remaining of the scripts to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon May 06 2019 alexl <alexl> 0.9.3b-6.git20181017.mga7
+ Revision: 1396417
- fix desktop file
- update Russian translation

* Sat Apr 20 2019 wally <wally> 0.9.3b-5.git20181017.mga7
+ Revision: 1393750
- rebuild for libgit2 0.28.1

* Sat Mar 30 2019 umeabot <umeabot> 0.9.3b-4.git20181017.mga7
+ Revision: 1381787
- Qt5 Rebuild

* Wed Jan 02 2019 daviddavid <daviddavid> 0.9.3b-3.git20181017.mga7
+ Revision: 1348742
- add patch to fix the logic to find the parts directory (mga#24114)

* Wed Jan 02 2019 daviddavid <daviddavid> 0.9.3b-2.git20181017.mga7
+ Revision: 1348730
- add missing dependency on qt5-database-plugin-sqlite (mga#24115)

* Wed Oct 17 2018 zezinho <zezinho> 0.9.3b-1.git20181017.mga7
+ Revision: 1321869
- shorter release

* Wed Oct 17 2018 zezinho <zezinho> 0.9.3b-0.git624187517fc89062a4e83d6c08d306863c0d4ec7.mga7
+ Revision: 1321496
- no release since 2016 so new version from today git 624187517fc89062a4e83d6c08d306863c0d4ec7

* Sun Sep 23 2018 umeabot <umeabot> 0.9.2-0.beta20150403.9.mga7
+ Revision: 1297787
- Mageia 7 Mass Rebuild

* Mon May 09 2016 luigiwalser <luigiwalser> 0.9.2-0.beta20150403.8.mga6
+ Revision: 1011760
- add patch from fedora to fix build with quazip
- use upstream .desktop file
- rebuild for quazip

* Sun Feb 14 2016 umeabot <umeabot> 0.9.2-0.beta20150403.7.mga6
+ Revision: 960196
- Mageia 6 Mass Rebuild

* Sat Jul 04 2015 alexl <alexl> 0.9.2-0.beta20150403.6.mga6
+ Revision: 849903
- enable external quazip (thanks to anaselli for fix)

* Fri Jul 03 2015 alexl <alexl> 0.9.2-0.beta20150403.5.mga6
+ Revision: 849760
- version 0.9.2b
- switch to qt5
- disable external quazip because of segfaults with open/save
- add additional fritzing man page
- update disable-autoupdate.patch

* Tue Jan 06 2015 alexl <alexl> 0.8.7-0.beta20140124.4.mga5
+ Revision: 808817
- changed GenericName in desktop file

* Wed Oct 15 2014 umeabot <umeabot> 0.8.7-0.beta20140124.3.mga5
+ Revision: 749053
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.7-0.beta20140124.2.mga5
+ Revision: 679360
- Mageia 5 Mass Rebuild

* Mon Apr 14 2014 alexl <alexl> 0.8.7-0.beta20140124.1.mga5
+ Revision: 613998
- imported package fritzing

